# coding: utf-8

"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""


import pprint
import re  # noqa: F401
from typing import TYPE_CHECKING

import six

from grid.openapi.configuration import Configuration

if TYPE_CHECKING:
    from datetime import datetime
    from grid.openapi.models import *

class ProtobufAny(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type_url': 'str',
        'value': 'str'
    }

    attribute_map = {
        'type_url': 'typeUrl',
        'value': 'value'
    }

    def __init__(self, type_url: 'str' = None, value: 'str' = None, _configuration=None):  # noqa: E501
        """ProtobufAny - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._type_url = None
        self._value = None
        self.discriminator = None

        if type_url is not None:
            self.type_url = type_url
        if value is not None:
            self.value = value

    @property
    def type_url(self) -> 'str':
        """Gets the type_url of this ProtobufAny.  # noqa: E501

        A URL/resource name that uniquely identifies the type of the serialized protocol buffer message. This string must contain at least one \"/\" character. The last segment of the URL's path must represent the fully qualified name of the type (as in `path/google.protobuf.Duration`). The name should be in a canonical form (e.g., leading \".\" is not accepted).  In practice, teams usually precompile into the binary all types that they expect it to use in the context of Any. However, for URLs which use the scheme `http`, `https`, or no scheme, one can optionally set up a type server that maps type URLs to message definitions as follows:  * If no scheme is provided, `https` is assumed. * An HTTP GET on the URL must yield a [google.protobuf.Type][]   value in binary format, or produce an error. * Applications are allowed to cache lookup results based on the   URL, or have them precompiled into a binary to avoid any   lookup. Therefore, binary compatibility needs to be preserved   on changes to types. (Use versioned type names to manage   breaking changes.)  Note: this functionality is not currently available in the official protobuf release, and it is not used for type URLs beginning with type.googleapis.com.  Schemes other than `http`, `https` (or the empty scheme) might be used with implementation specific semantics.  # noqa: E501

        :return: The type_url of this ProtobufAny.  # noqa: E501
        :rtype: str
        """
        return self._type_url

    @type_url.setter
    def type_url(self, type_url: 'str'):
        """Sets the type_url of this ProtobufAny.

        A URL/resource name that uniquely identifies the type of the serialized protocol buffer message. This string must contain at least one \"/\" character. The last segment of the URL's path must represent the fully qualified name of the type (as in `path/google.protobuf.Duration`). The name should be in a canonical form (e.g., leading \".\" is not accepted).  In practice, teams usually precompile into the binary all types that they expect it to use in the context of Any. However, for URLs which use the scheme `http`, `https`, or no scheme, one can optionally set up a type server that maps type URLs to message definitions as follows:  * If no scheme is provided, `https` is assumed. * An HTTP GET on the URL must yield a [google.protobuf.Type][]   value in binary format, or produce an error. * Applications are allowed to cache lookup results based on the   URL, or have them precompiled into a binary to avoid any   lookup. Therefore, binary compatibility needs to be preserved   on changes to types. (Use versioned type names to manage   breaking changes.)  Note: this functionality is not currently available in the official protobuf release, and it is not used for type URLs beginning with type.googleapis.com.  Schemes other than `http`, `https` (or the empty scheme) might be used with implementation specific semantics.  # noqa: E501

        :param type_url: The type_url of this ProtobufAny.  # noqa: E501
        :type: str
        """

        self._type_url = type_url

    @property
    def value(self) -> 'str':
        """Gets the value of this ProtobufAny.  # noqa: E501

        Must be a valid serialized protocol buffer of the above specified type.  # noqa: E501

        :return: The value of this ProtobufAny.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value: 'str'):
        """Sets the value of this ProtobufAny.

        Must be a valid serialized protocol buffer of the above specified type.  # noqa: E501

        :param value: The value of this ProtobufAny.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                value is not None and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', value)):  # noqa: E501
            raise ValueError(r"Invalid value for `value`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._value = value

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProtobufAny, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'ProtobufAny') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, ProtobufAny):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other: 'ProtobufAny') -> bool:
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProtobufAny):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""


import pprint
import re  # noqa: F401
from typing import TYPE_CHECKING

import six

from grid.openapi.configuration import Configuration

if TYPE_CHECKING:
    from datetime import datetime
    from grid.openapi.models import *

class V1ExperimentEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'desired_state': 'V1ExperimentState',
        'id': 'str',
        'message': 'str',
        'phase': 'V1ExperimentState',
        'timestamp': 'datetime'
    }

    attribute_map = {
        'desired_state': 'desiredState',
        'id': 'id',
        'message': 'message',
        'phase': 'phase',
        'timestamp': 'timestamp'
    }

    def __init__(self, desired_state: 'V1ExperimentState' = None, id: 'str' = None, message: 'str' = None, phase: 'V1ExperimentState' = None, timestamp: 'datetime' = None, _configuration=None):  # noqa: E501
        """V1ExperimentEvent - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._desired_state = None
        self._id = None
        self._message = None
        self._phase = None
        self._timestamp = None
        self.discriminator = None

        if desired_state is not None:
            self.desired_state = desired_state
        if id is not None:
            self.id = id
        if message is not None:
            self.message = message
        if phase is not None:
            self.phase = phase
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def desired_state(self) -> 'V1ExperimentState':
        """Gets the desired_state of this V1ExperimentEvent.  # noqa: E501


        :return: The desired_state of this V1ExperimentEvent.  # noqa: E501
        :rtype: V1ExperimentState
        """
        return self._desired_state

    @desired_state.setter
    def desired_state(self, desired_state: 'V1ExperimentState'):
        """Sets the desired_state of this V1ExperimentEvent.


        :param desired_state: The desired_state of this V1ExperimentEvent.  # noqa: E501
        :type: V1ExperimentState
        """

        self._desired_state = desired_state

    @property
    def id(self) -> 'str':
        """Gets the id of this V1ExperimentEvent.  # noqa: E501


        :return: The id of this V1ExperimentEvent.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1ExperimentEvent.


        :param id: The id of this V1ExperimentEvent.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def message(self) -> 'str':
        """Gets the message of this V1ExperimentEvent.  # noqa: E501


        :return: The message of this V1ExperimentEvent.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message: 'str'):
        """Sets the message of this V1ExperimentEvent.


        :param message: The message of this V1ExperimentEvent.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def phase(self) -> 'V1ExperimentState':
        """Gets the phase of this V1ExperimentEvent.  # noqa: E501


        :return: The phase of this V1ExperimentEvent.  # noqa: E501
        :rtype: V1ExperimentState
        """
        return self._phase

    @phase.setter
    def phase(self, phase: 'V1ExperimentState'):
        """Sets the phase of this V1ExperimentEvent.


        :param phase: The phase of this V1ExperimentEvent.  # noqa: E501
        :type: V1ExperimentState
        """

        self._phase = phase

    @property
    def timestamp(self) -> 'datetime':
        """Gets the timestamp of this V1ExperimentEvent.  # noqa: E501


        :return: The timestamp of this V1ExperimentEvent.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp: 'datetime'):
        """Sets the timestamp of this V1ExperimentEvent.


        :param timestamp: The timestamp of this V1ExperimentEvent.  # noqa: E501
        :type: datetime
        """

        self._timestamp = timestamp

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ExperimentEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1ExperimentEvent') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ExperimentEvent):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other: 'V1ExperimentEvent') -> bool:
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1ExperimentEvent):
            return True

        return self.to_dict() != other.to_dict()



from typing import List, Optional

from grid.metadata import __version__
from grid.sdk.client import create_gql_client
from grid.sdk.client.grid_gql import gql_execute


def get_grid_user_id(client) -> str:
    query = """
    query Login ($cliVersion: String!) {
        cliLogin (cliVersion: $cliVersion) {
            userId
            success
            message
        }
    }
    """
    res = gql_execute(client, query, cliVersion=__version__)['cliLogin']
    return res['userId']


def get_user_basic_info():
    client = create_gql_client()
    query = """
    query {
        getUser {
            userId
            isVerified
            completedSignup
            isBlocked
            username
            firstName
            lastName
            email
        }
    }
    """
    return gql_execute(client, query)['getUser']


def get_user_teams() -> List[dict]:
    client = create_gql_client()
    query = """
        query GetUserTeams {
            getUserTeams {
                success
                message
                teams {
                    id
                    name
                    createdAt
                    role
                    members {
                        id
                        username
                        firstName
                        lastName
                    }
                }
            }
        }
    """
    result = gql_execute(client, query)
    if not result['getUserTeams'] or not result['getUserTeams']['success']:
        raise RuntimeError(result['getUserTeams']["message"])
    return result['getUserTeams']['teams']


def get_user_info():
    """Return basic information about a user."""
    client = create_gql_client()
    query = """
        query {
            getUser {
                username
                firstName
                lastName
                email

            }
        }
    """

    result = gql_execute(client, query)
    if not result['getUser']:
        raise RuntimeError(result['getUser']["message"])
    return result['getUser']


def create_datastore(name: str, source: str, cluster: Optional[str] = None):
    """Create datastore in Grids
    """
    # Create Grid datastore directly in Grid without uploading, since Grid will
    # handle extraction and creating a optimizted datastore automatically.
    client = create_gql_client()
    mutation = """
        mutation (
            $name: String!
            $source: String
            $clusterId: String
            ) {
            createDatastore (
                properties: {
                        name: $name
                        source: $source
                        clusterId: $clusterId
                    }
            ) {
            success
            message
            datastoreId
            datastoreVersion
            }
        }
    """

    params = {'name': name, 'source': source, 'clusterId': cluster}
    result = gql_execute(client, mutation, **params)
    success = result['createDatastore']['success']
    message = result['createDatastore']['message']
    if not success:
        raise ValueError(f"Unable to create datastore: {message}")

    res = result['createDatastore']
    res['datastoreVersion'] = int(res['datastoreVersion'])
    return res


def get_user():
    client = create_gql_client()
    query = """
        query {
            getUser {
                isVerified
                completedSignup
                isBlocked
            }
        }
        """
    result = gql_execute(client, query)
    return result["getUser"]
